pyyaml: YAML parser and emitter for Python
==========================================

Description
-----------

YAML parser and emitter for Python

License
-------

MIT

Upstream Contact
----------------

https://pypi.org/project/PyYAML/

